/*****************************************************************************
 *                     Yumetech, Inc Copyright (c) 2004-2005
 *                               Java Source
 *
 * This source is licensed under the GNU LGPL v2.1
 * Please read http://www.gnu.org/copyleft/lgpl.html for more information
 *
 * This software comes with the standard NO WARRANTY disclaimer for any
 * purpose. Use it at your own risk. If there's a problem you get to fix it.
 *
 ****************************************************************************/

package org.j3d.aviatrix3d;

// External imports
// None

// Local imports
// None

/**
 * A Leaf class is the base class for all scene graph objects that have no
 * children but provide something that may be renderable in the scene graph.
 *
 * @author Alan Hudson
 * @version $Revision: 1.5 $
 */
public abstract class Leaf extends Node
{
    /**
     * Get the {@link Renderable} instance needed to process this object for
     * the given buffer ID. The renderable instance should encapsulate all the
     * data needed to render this object in a thread-safe way. The default
     * implementation of this method returns null, indicating that this does
     * not provide anything useful to the pipeline to render. Classes that wish
     * to be rendered, should override this method and provide an appropriate
     * return value.
     * <p>
     * Note: This should never be called by end-user code. It is publically
     * accessible for code that is used by the rendering pipeline
     * implementation, such as culling and sorting stages.
     *
     * @param bufferId The ID of the buffer for the renderable to encapsulate
     * @return The renderable object, or null if nothing to render
     */
    public Renderable getRenderable(int bufferId)
    {
        return null;
    }
}
